/*
 * Copyright 2017 Google Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef LEARNING_GENOMICS_DEEPVARIANT_POSTPROCESS_VARIANTS_H_
#define LEARNING_GENOMICS_DEEPVARIANT_POSTPROCESS_VARIANTS_H_

#include <string>
#include <vector>

#include "deepvariant/core/protos/core.pb.h"
#include "deepvariant/protos/deepvariant.pb.h"
#include "tensorflow/core/lib/core/stringpiece.h"

namespace learning {
namespace genomics {
namespace deepvariant {

using tensorflow::uint64;
using tensorflow::string;
using tensorflow::StringPiece;

// Reads TFRecord of CallVariantsOutput protos, sort them based
// on the mapping of chromosome names to positions in FASTA in `contigs`,
// and then outputs the sorted TFRecord of CallVariantsOutput protos to
// `output_tfrecord_path`.
void ProcessSingleSiteCallTfRecords(
    const std::vector<core::ContigInfo>& contigs,
    const std::vector<string>& tfrecord_paths,
    const string& output_tfrecord_path);

}  // namespace deepvariant
}  // namespace genomics
}  // namespace learning

#endif  // LEARNING_GENOMICS_DEEPVARIANT_POSTPROCESS_VARIANTS_H_
