/*
 * Copyright 2017 Google Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include "deepvariant/vendor/statusor.h"
#include "deepvariant/vendor/status_matchers.h"
#include "tensorflow/core/platform/test.h"
#include "tensorflow/core/lib/core/status.h"

namespace learning {
namespace genomics {

using tensorflow::Status;

// Status tests.
TEST(StatusTest, OKStatusMatchesIsOK) {
  EXPECT_THAT(Status::OK(), IsOK());
}

TEST(StatusTest, FailedStatusMatchesIsNotOK) {
  EXPECT_THAT(tensorflow::errors::Unknown("fail"), IsNotOK());
}

TEST(StatusTest, FailedStatusMatchesIsNotOKCode) {
  EXPECT_THAT(tensorflow::errors::Unknown("fail"),
              IsNotOKWithCode(tensorflow::error::UNKNOWN));
}

TEST(StatusTest, FailedStatusMatchesIsNotOKWithMessage) {
  EXPECT_THAT(tensorflow::errors::Unknown("fail"), IsNotOKWithMessage("fail"));
}

TEST(StatusTest, FailedStatusMatchesIsNotOKWithCodeAndMessage) {
  EXPECT_THAT(tensorflow::errors::Unknown("fail"),
              IsNotOKWithCodeAndMessage(tensorflow::error::UNKNOWN, "fail"));
}

// StatusOr tests.
TEST(StatusOrTest, OKStatusMatchesIsOK) {
  StatusOr<int> status_or = StatusOr<int>(0);
  EXPECT_THAT(status_or, IsOK());
}

TEST(StatusOrTest, FailedStatusMatchesIsNotOK) {
  StatusOr<int> status_or = tensorflow::errors::Unknown("fail");
  EXPECT_THAT(status_or, IsNotOK());
}

TEST(StatusOrTest, FailedStatusMatchesIsNotOKCode) {
  StatusOr<int> status_or = tensorflow::errors::Unknown("fail");
  EXPECT_THAT(status_or, IsNotOKWithCode(tensorflow::error::UNKNOWN));
}

TEST(StatusOrTest, FailedStatusMatchesIsNotOKWithMessage) {
  StatusOr<int> status_or = tensorflow::errors::Unknown("fail");
  EXPECT_THAT(status_or, IsNotOKWithMessage("fail"));
}

TEST(StatusOrTest, FailedStatusMatchesIsNotOKWithCodeAndMessage) {
  StatusOr<int> status_or = tensorflow::errors::Unknown("fail");
  EXPECT_THAT(status_or,
              IsNotOKWithCodeAndMessage(tensorflow::error::UNKNOWN, "fail"));
}

}  // namespace genomics
}  // namespace learning
